@@ -5,7 +5,7 @@ from django.core.files import File
 from django.core.urlresolvers import reverse
 from django.db import transaction
 from django.forms.models import model_to_dict
-from django.forms.util import ErrorList
+from django.forms.utils import ErrorList
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import render_to_response, redirect
 from django.template import RequestContext
@@ -14,10 +14,9 @@ from guardian.shortcuts import remove_perm
 from ldt.ldt_utils.forms import ContentForm, MediaForm
 from ldt.ldt_utils.models import Content, Media, Project
 from ldt.security.cache import cached_assign
-from ldt.security.utils import (assign_perm_to_obj, add_change_attr, get_userlist, 
+from ldt.security.utils import (assign_perm_to_obj, add_change_attr, get_userlist,
     get_userlist_model)
 from ldt.user.forms import PictureForm
-from tagging.models import Tag, TaggedItem
 import datetime
 import ldt.utils.path as ldt_utils_path
 import logging
@@ -33,6 +32,7 @@ import traceback
 import urllib2
 import urlparse
 #from django.core.files.temp import NamedTemporaryFile
+logger = logging.getLogger(__name__)
 
 def media_management(request, media_input_type, cleaned_data, content_form, media_form, form_status):
     if media_input_type == "none":
@@ -53,20 +53,21 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
             # If the url is kind of rtmp://site/flv:path/to/file.flv or rtmp://site/mp4:path/to/file.mp4, we parse it.
             # If the url is kind of rtmp://site/path/to/file, we don't parse it because we can't get the right streamer.
             a = cleaned_data['src'].split(":")
-            if len(a)==3 and (a[1].endswith("flv") or a[1].endswith("mp4") or a[1].endswith("mp3")):
+            filepart = a[1].lower() if len(a) == 3 else ""
+            if len(a)==3 and (filepart.endswith("flv") or filepart.endswith("mp4") or filepart.endswith("mp3")):
                 # We update with the good streamer
                 cleaned_data['videopath'] = a[0] + ":" + a[1][:-3]
                 # We remove the "flv:" from the url because it's useless in the real url
-                if a[1].endswith("flv"):
+                if filepart.endswith("flv"):
                     cleaned_data['src'] = a[2]
                 else:
                     cleaned_data['src'] = a[1][-3:] + ":" + a[2]
                 # We remove the ".mp3" at the the end of the src if necessary
-                if a[1].endswith("mp3") and cleaned_data['src'].endswith(".mp3"):
+                if filepart.endswith("mp3") and cleaned_data['src'].endswith(".mp3"):
                     cleaned_data['src'] = cleaned_data['src'][:-4]
         # We get or create the media with the correct datas
         media, created = Media.objects.get_or_create(src=cleaned_data['src'], defaults=cleaned_data) #@UndefinedVariable
-    
+
     elif media_input_type == "url" or media_input_type == "upload" :
         # copy file
         #complet src
@@ -83,7 +84,7 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
                 #source_file = request.FILES['media-media_file']
                 # At this point the file has already be uploaded thanks to the upload view, and original file name is sent through a post var
                 source_filename = request.POST["media-local_file_name"]
-            
+
             source_filename = ldt_utils_path.sanitize_filename(source_filename)
             destination_filepath = os.path.join(settings.STREAM_PATH, source_filename)
             base_source_filename = source_filename
@@ -94,12 +95,12 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
             else:
                 base_basename_filename = base_source_filename[:-1 * (len(extension) + 1)]
             i = 0
-            
+
             while os.path.exists(destination_filepath):
                 base_source_filename = "%s.%d.%s" % (base_basename_filename, i, extension)
                 destination_filepath = os.path.join(settings.STREAM_PATH, base_source_filename)
                 i += 1
-            
+
             if media_input_type == "url":
                 # we upload the file if we are in url case
                 destination_file = open(destination_filepath, "wb")
@@ -107,23 +108,22 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
                 while chunck:
                     destination_file.write(chunck)
                     chunck = source_file.read(2048)
-                
+
             elif media_input_type == "upload":
-                # The media file has been uploaded in the session temp folder 
+                # The media file has been uploaded in the session temp folder
                 # so we just have to move to the regular folder and rename it.
                 if os.path.exists(os.path.join(settings.STREAM_PATH, "tmp/" + request.COOKIES[settings.SESSION_COOKIE_NAME] + "/", source_filename)):
                     os.rename(os.path.join(settings.STREAM_PATH, "tmp/" + request.COOKIES[settings.SESSION_COOKIE_NAME] + "/", source_filename), os.path.join(settings.STREAM_PATH, base_source_filename))
-            
-            
+
+
             src_prefix = settings.STREAM_SRC_PREFIX.rstrip("/")
             if len(src_prefix) > 0:
                 cleaned_data["src"] = src_prefix + "/" + base_source_filename
             else:
                 cleaned_data["src"] = base_source_filename
-            
-            
+
+
         except Exception as inst:
-            logging.debug("write_content_base : POST error when processing file:" + str(inst)) #@UndefinedVariable
             form_status = "error"
             #set error for form
             if media_input_type == "url":
@@ -138,8 +138,8 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
                     destination_file.close()
                 if source_file:
                     source_file.close()
-        
-        
+
+
         if form_status != "error":
             del cleaned_data["media_file"]
             if not cleaned_data['videopath']:
@@ -152,7 +152,7 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
             cached_assign('view_media', request.user, media)
         else:
             media = None
-            
+
 
     if media and not created:
         for attribute in ('external_id', 'external_permalink', 'external_publication_url', 'external_src_url', 'media_creation_date', 'videopath', 'duration', 'description', 'title', 'front_project'):
@@ -164,16 +164,15 @@ def media_management(request, media_input_type, cleaned_data, content_form, medi
         cached_assign('view_media', request.user, media)
         cached_assign('change_media', request.user, media)
         media.save()
-        
+
     return media, form_status
-    
-    
-@transaction.commit_manually
+
+
+@transaction.atomic
 def write_content_base(request, iri_id=None):
     if iri_id:
-        instance_content = Content.safe_objects.get(iri_id=iri_id) #@UndefinedVariable
+        instance_content = Content.safe_objects.select_related('media_obj','front_project').get(iri_id=iri_id) #@UndefinedVariable
         instance_media = instance_content.media_obj
-        logging.debug("write_content_base : valid form: for instance : media -> " + repr(instance_media) + " content : for instance : " + repr(instance_content)) #@UndefinedVariable
     else:
         logging.debug("No iri_id") #@UndefinedVariable
         instance_content = None
@@ -182,46 +181,46 @@ def write_content_base(request, iri_id=None):
     if instance_content:
         current_front_project = instance_content.front_project
     form_status = 'none'
-    
+
     if request.method == "POST":
         try:
             if instance_content is not None:
                 content_instance_val = model_to_dict(instance_content, exclude=ContentForm.Meta.exclude)
             else:
                 content_instance_val = {}
-            
+
             if instance_media is not None:
                 media_instance_val = model_to_dict(instance_media, exclude=MediaForm.Meta.exclude)
             else:
                 media_instance_val = {}
             #add prefix
-            
+
             def add_prefix(_dict, prefix):
                 return dict([('%s-%s' % (prefix, key), value) for key,value in _dict.items()])
-            
+
             content_instance_val = add_prefix(content_instance_val, "content")
-            media_instance_val= add_prefix(media_instance_val, "media")    
-                    
+            media_instance_val= add_prefix(media_instance_val, "media")
+
             for k in request.POST.keys():
                 value = request.POST.get(k)
                 content_instance_val[k] = value
                 media_instance_val[k] = value
-                
+
             content_instance_val['read_list'] = request.POST.getlist('read_list')
             content_instance_val['write_list'] = request.POST.getlist('write_list')
             content_instance_val['share'] = request.POST.get('share', True)
-            
+
             content_form = ContentForm(content_instance_val, prefix="content", instance=instance_content)
             media_form = MediaForm(media_instance_val, request.FILES, prefix="media", instance=instance_media)
             picture_form = PictureForm(None, request.POST, request.FILES)
-       
+
             if request.user.is_staff:
                 content_form.fields['front_project'].queryset = Project.objects.filter(contents__in=[instance_content])
-            
+
             media_valid = media_form.is_valid()
             content_valid = content_form.is_valid()
             picture_valid = picture_form.is_valid()
-            
+
             if 'image' in request.POST.keys():
                 image_link = request.POST.get('url_image')
                 if picture_valid and image_link!='' :
@@ -231,39 +230,45 @@ def write_content_base(request, iri_id=None):
                         if img_temp:
                             img_temp.write(r.content)
                             img_temp.flush()
-                            picture_form.cleaned_data["image"]=File(img_temp) 
-                    except Exception as inst:
+                            picture_form.cleaned_data["image"]=File(img_temp)
+                    except Exception:
                         logging.debug("couldn't download video thumbnail from image_link : " + str(image_link))
-            logging.debug("write_content_base : valid form: for instance : " + repr(instance_media) + " -> media " + str(media_valid) + " content : for instance : " + repr(instance_content) + " : " + str(content_valid) + "picture : valid :" +str(picture_valid)) #@UndefinedVariable
-            
+
             if media_valid and content_valid and picture_valid:
-    
+
                 # see if media must be created
                 cleaned_data = {}
                 cleaned_data.update(media_form.cleaned_data)
                 cleaned_data.pop("media_public")
-                
+
                 media_input_type = content_form.cleaned_data["media_input_type"]
-                
+
                 media, form_status = media_management(request, media_input_type, cleaned_data, content_form, media_form, form_status)
-                
-                if form_status != "error": 
+
+                if form_status != "error":
                     content_defaults = {}
                     content_defaults.update(content_form.cleaned_data)
                     content_defaults['media_obj'] = media
-                                   
+
                     for key in ["media_input_type", "groups", "is_public", "read_list", "write_list", "share" ]:
                         del content_defaults[key]
-                        
+
+                    #taggit management : save tags and add them after get_or_create
+                    saved_tags = content_defaults.get('tags') or []
+                    logger.debug(saved_tags)
+                    content_defaults.pop('tags')
+                    logger.debug(content_defaults)
                     content, created = Content.safe_objects.get_or_create(iri_id=content_form.cleaned_data['iri_id'], defaults=content_defaults) #@UndefinedVariable
-                                      
+                    content.tags.clear()
+                    for t in saved_tags:
+                        content.tags.add(t)
+                    logger.debug(content.tags.names())
+
                     if not created and not request.user.has_perm('ldt_utils.change_content', content):
                         raise AttributeError("%s is not allowed to change content %s" % (request.user, content))
-                    
                     cached_assign('change_content', request.user, content)
                     cached_assign('view_content', request.user, content)
                     everyone = Group.objects.get(name=settings.PUBLIC_GROUP_NAME)
-                    
                     if media_form.cleaned_data['media_public']:
                         cached_assign('view_content', everyone, content)
                         if media:
@@ -277,17 +282,15 @@ def write_content_base(request, iri_id=None):
                             cached_assign('view_content', everyone, content)
                         else:
                             remove_perm('ldt_utils.view_content', everyone, content)
-                    
                     if not created:
-                        for attribute in ('iriurl', 'title', 'description', 'duration', 'content_creation_date', 'tags', 'media_obj'):
+                        for attribute in ('iriurl', 'title', 'description', 'duration', 'content_creation_date', 'media_obj'):
                             setattr(content, attribute, content_defaults[attribute])
-                            
+
                         if request.user.is_staff and content_defaults.has_key('front_project'):
                             content.front_project = content_defaults['front_project']
-                    
                     content.save()
                     picture_form.model = content
-                    picture_form.save()  
+                    picture_form.save()
                     form_status = 'saved'
                     media_form = MediaForm(instance=media, prefix="media")
                     content_form = ContentForm(instance=content, prefix="content")
@@ -295,10 +298,9 @@ def write_content_base(request, iri_id=None):
             else:
                 form_status = 'error'
         except Exception, e:
-            transaction.rollback()
             __, value, traceback = sys.exc_info()
-            return False, False, False, False, False, e, traceback
-            
+            return False, False, False, False, False, False, e, traceback
+
     else:
         form_status = 'empty'
         initial_c = { 'media_input_type':"link"}
@@ -312,31 +314,24 @@ def write_content_base(request, iri_id=None):
         else:
             initial_c['is_public'] = True
         content_form = ContentForm(prefix="content", instance=instance_content, initial=initial_c)
-        media_form = MediaForm(prefix="media", instance=instance_media, initial=initial_m) 
-        picture_form = PictureForm() 
-                
+        media_form = MediaForm(prefix="media", instance=instance_media, initial=initial_m)
+        picture_form = PictureForm()
+
         if instance_content is not None:
             content_form.media_input_type = "link"
-                   
+
             if request.user.is_staff:
                 content_form.fields['front_project'].queryset = Project.objects.filter(contents__in=[instance_content])
-    
-    try:
-        transaction.commit()
-    except Exception, e:
-        transaction.rollback()
-        __, __, traceback = sys.exc_info()
-        return False, False, False, False, False, e, traceback
-        
-    return content_form, media_form, picture_form, form_status, current_front_project, "", ""
+
+    return content_form, media_form, picture_form, form_status, instance_content, current_front_project, "", ""
 
 @login_required
-def write_content(request, iri_id=None):  
-    submit_action = request.REQUEST.get("submit_button", False) 
+def write_content(request, iri_id=None):
+    submit_action = request.REQUEST.get("submit_button", False)
     member_list = admin_list = []
     current_front_project = None
     content_deleted = None
-    
+
     if submit_action == "prepare_delete":
         errors, titles, message_temp = prepare_delete_content(request, iri_id)
         if errors and len(errors) > 0:
@@ -345,10 +340,10 @@ def write_content(request, iri_id=None):
         else:
             if len(message_temp)>0:
                 message = message_temp
-            else:    
+            else:
                 message = _("Confirm delete content %(titles)s") % { 'titles' : ",".join(titles) }
             title_msg = _("confirm delete content")
-        return render_to_response('ldt/ldt_utils/error_confirm.html', {'errors':errors, 'message':message, 'title': title_msg}, context_instance=RequestContext(request))  
+        return render_to_response('ldt/ldt_utils/error_confirm.html', {'errors':errors, 'message':message, 'title': title_msg}, context_instance=RequestContext(request))
     elif submit_action == "delete":
         content_deleted, e, traceback = delete_content(request, iri_id)
         content_form = ContentForm()
@@ -370,7 +365,7 @@ def write_content(request, iri_id=None):
         return render_to_response('ldt/ldt_utils/reset_confirm.html', {'errors':errors, 'message':message, 'title': title}, context_instance=RequestContext(request))
     elif submit_action == "reset":
         #TODO : verifier index de la recherche maj
-        content = Content.objects.get(iri_id=iri_id)
+        content = Content.objects.get(iri_id=iri_id).select_related('front_project')
         project_temp = content.front_project
         content.create_front_project()
         content.save()
@@ -379,23 +374,25 @@ def write_content(request, iri_id=None):
     elif submit_action=="close":
         return redirect("root-view")
     else:
-        content_form, media_form, picture_form, form_status, current_front_project, e, traceback = write_content_base(request, iri_id)        
-        if iri_id: 
-            content_temp = Content.objects.get(iri_id=iri_id)
+        content_form, media_form, picture_form, form_status, content_temp, current_front_project, e, traceback = write_content_base(request, iri_id)
+
+        if content_form == False and media_form == False and picture_form == False and form_status == False and current_front_project == False and content_temp == False:
+
+            message=_("An error occurred - Please try again or contact webmaster")
+            title = _("Error")
+            raise e, None, traceback
+
+        if iri_id:
+            #content_temp = Content.objects.select_related('media_obj').get(iri_id=iri_id)
             media_temp = content_temp.media_obj
             if media_temp:
                 member_list, admin_list = get_userlist_model(media_temp, request.user)
             else:
                 member_list, admin_list = get_userlist_model(content_temp, request.user)
-    
-        if (content_form == False and media_form == False and picture_form == False and form_status == False and current_front_project == False):
-            message=_("An error occurred - Please try again or contact webmaster")
-            title = _("Error")
-            raise e, None, traceback
-    
+
     if content_deleted == False:
         raise e, None, traceback
-    
+
     if iri_id:
         create_content_action = reverse('ldt.ldt_utils.views.content.write_content', kwargs={'iri_id':iri_id})
         img_container = content_form.instance
@@ -403,14 +400,14 @@ def write_content(request, iri_id=None):
     else:
         create_content_action = reverse('ldt.ldt_utils.views.content.write_content')
         img_container = ''
-    
+
     session_key = request.COOKIES[settings.SESSION_COOKIE_NAME]
     cookie_name = settings.SESSION_COOKIE_NAME
     # Media.safe_objects.all() does not return the good list of media, so we get them from the Content.safe_objects
     content_form.fields["media_obj"].queryset = Media.objects.filter(id__in=Content.safe_objects.values_list('media_obj', flat=True))
-    
+
     if form_status=='saved' or form_status=='deleted':
-        return redirect("root-view") 
+        return redirect("root-view")
     else:
         group_list = Group.objects.all()
         group_list = group_list.exclude(name=settings.PUBLIC_GROUP_NAME)
@@ -421,15 +418,15 @@ def write_content(request, iri_id=None):
                                                                     'cookie_name':cookie_name, 'img_container': img_container, 'profile_picture_form': picture_form,
                                                                     'current_front_project':current_front_project}, context_instance=RequestContext(request))
 @login_required
-def prepare_delete_content(request, iri_id=None): 
+def prepare_delete_content(request, iri_id=None):
     errors = []
     titles = []
     message={}
     if not iri_id:
         iri_id = request.REQUEST.get("iri_id", None)
-        
+
     if iri_id:
-        for content in Content.safe_objects.filter(iri_id=iri_id): 
+        for content in Content.safe_objects.filter(iri_id=iri_id):
             titles.append(unicode(content.title))
             projects = content.project_set.all()
             projects_nb = len(projects)
@@ -443,12 +440,11 @@ def prepare_delete_content(request, iri_id=None):
 
 
 @login_required
-@transaction.commit_manually
+@transaction.atomic
 def delete_content(request, iri_id=None):
     #Delete the project, the media if exists, and the content
-    errors_transaction=[]  
     if not iri_id:
-        iri_id = request.REQUEST.get("iri_id", None)  
+        iri_id = request.REQUEST.get("iri_id", None)
     if iri_id:
         content = Content.safe_objects.get(iri_id=iri_id)
         try:
@@ -462,20 +458,9 @@ def delete_content(request, iri_id=None):
             if project is not None:
                 Project.safe_objects.get(ldt_id= project.ldt_id).delete()
         except Exception, e:
-            content.rollback()
-            transaction.rollback()
             __, __, traceback = sys.exc_info()
             return False, e, traceback
-        else:
-            try:
-                transaction.commit()
-                content.commit()
-                return True, "", ""
-            except Exception, e:
-                content.rollback()
-                transaction.rollback()
-                __, __, traceback = sys.exc_info()
-                return False, e, traceback
+        return True, "", ""
 
 def upload(request):
     if request.method == 'POST':
@@ -492,24 +477,24 @@ def upload(request):
             # We delete the existing file if necessary
             if os.path.exists(destination_filepath):
                 os.remove(destination_filepath)
-            
+
             destination_file = open(destination_filepath, "wb")
-            
+
             for chunk in source_file.chunks():
                 destination_file.write(chunk)
             destination_file.close()
-            
+
         # indicate that everything is OK for SWFUpload
-        return HttpResponse("ok", mimetype="text/plain")
+        return HttpResponse("ok", content_type="text/plain")
     else:
-        return HttpResponse("notok", mimetype="text/plain")
+        return HttpResponse("notok", content_type="text/plain")
 
 def remove_temp_file(request):
     # The filename arrives with a GET var.
     file_path = os.path.join(settings.STREAM_PATH, "tmp/" + request.COOKIES[settings.SESSION_COOKIE_NAME] + "/", ldt_utils_path.sanitize_filename(request.GET["filename"]))
     if os.path.exists(file_path):
         os.remove(file_path)
-    return HttpResponse("remove ok", mimetype="text/plain")
+    return HttpResponse("remove ok", content_type="text/plain")
 
 def get_duration(request):
     try:
@@ -521,53 +506,50 @@ def get_duration(request):
             dur_arr = m.group(1).split(":")
             td = datetime.timedelta(hours=int(dur_arr[0]), minutes=int(dur_arr[1]), seconds=float(dur_arr[2]))
             str_duration = str((td.microseconds + (td.seconds + td.days * 24 * 3600) * 10 ** 6) / 10 ** 3)
-            return HttpResponse(str_duration, mimetype="text/plain")
+            return HttpResponse(str_duration, content_type="text/plain")
         else:
-            return HttpResponse("", mimetype="text/plain")
+            return HttpResponse("", content_type="text/plain")
     except Exception as inst:
-        return HttpResponse(str(inst), mimetype="text/plain")
+        return HttpResponse(str(inst), content_type="text/plain")
+
 
-    
 @login_required
-def contents_filter(request, filter_c): 
+def contents_filter(request, filter_c):
     if filter_c and len(filter_c) > 0 and filter_c[0] == '_':
         filter_c = filter_c[1:]
-    
+
     num_page = 0
     if request.GET.has_key('num_page'):
         num_page = int(request.GET["num_page"])
     tag_filter = ""
     if request.GET.has_key('tag_filter'):
         tag_filter = request.GET["tag_filter"]
-    
+
     # We paginate the content list, in case of filter_c or not
     if filter_c and not tag_filter :
         content_nb = Content.safe_objects.filter(title__icontains=filter_c).count()
         nb_ct_pages = int(math.ceil(content_nb / settings.LDT_MAX_CONTENTS_PER_PAGE)) + 1
         content_list = Content.safe_objects.filter(title__icontains=filter_c)[(num_page*settings.LDT_MAX_CONTENTS_PER_PAGE):((num_page+1)*settings.LDT_MAX_CONTENTS_PER_PAGE)] #@UndefinedVariable
     elif filter_c and tag_filter :
-        #TaggedItem.objects.get_by_model(Content.objects.all(), '"'+tag_filter+'"')
-        content_nb = TaggedItem.objects.get_by_model(Content.safe_objects.filter(title__icontains=filter_c), '"'+tag_filter+'"').count()
+        content_nb = Content.objects.filter(title__icontains=filter_c, tags__name__in=tag_filter).distinct().count()
         nb_ct_pages = int(math.ceil(content_nb / settings.LDT_MAX_CONTENTS_PER_PAGE)) + 1
-        content_list = TaggedItem.objects.get_by_model(Content.safe_objects.filter(title__icontains=filter_c), '"'+tag_filter+'"')[(num_page*settings.LDT_MAX_CONTENTS_PER_PAGE):((num_page+1)*settings.LDT_MAX_CONTENTS_PER_PAGE)] #@UndefinedVariable
+        content_nb = Content.objects.filter(title__icontains=filter_c, tags__name__in=tag_filter).distinct()[(num_page*settings.LDT_MAX_CONTENTS_PER_PAGE):((num_page+1)*settings.LDT_MAX_CONTENTS_PER_PAGE)]
     elif tag_filter and not filter_c:
-        content_nb = TaggedItem.objects.get_by_model(Content.safe_objects.all(), '"'+tag_filter+'"').count()
-        nb_ct_pages = int(math.ceil(content_nb / settings.LDT_MAX_CONTENTS_PER_PAGE)) +1
-        content_list = TaggedItem.objects.get_by_model(Content.safe_objects.all(), '"'+tag_filter+'"')[(num_page*settings.LDT_MAX_CONTENTS_PER_PAGE):((num_page+1)*settings.LDT_MAX_CONTENTS_PER_PAGE)] #@UndefinedVariable
+        content_nb = Content.safe_objects.select_related('stat_annotation').filter(tags__name__in=[tag_filter]).distinct().count()
+        nb_ct_pages = int(math.ceil(content_nb / settings.LDT_MAX_CONTENTS_PER_PAGE)) + 1
+        content_list = Content.safe_objects.select_related('stat_annotation').filter(tags__name__in=[tag_filter]).distinct()[(num_page*settings.LDT_MAX_CONTENTS_PER_PAGE):((num_page+1)*settings.LDT_MAX_CONTENTS_PER_PAGE)] #@UndefinedVariable
     else:
         content_nb, nb_ct_pages, content_list = get_contents_page(num_page, request.user)
     #Change attributes with object permissions
     content_list = add_change_attr(request.user, content_list)
-    # Get the all tags list
-    tag_cloud = get_content_tags()
-    
+
     is_gecko = ((request.META['HTTP_USER_AGENT'].lower().find("firefox")) > -1);
     return render_to_response("ldt/ldt_utils/partial/contentslist.html",
                               {'contents': content_list, 'nb_ct_pages': nb_ct_pages, 'content_nb': content_nb, 'current_content_page':float(num_page),
-                               'tag_cloud': tag_cloud, 'current_content_tag':tag_filter, 'is_gecko': is_gecko
+                               'current_content_tag':tag_filter, 'is_gecko': is_gecko
                                },
                               context_instance=RequestContext(request))
-    
+
 
 def get_contents_page(num_page, user):
     content_nb = float(Content.safe_objects.count()) #@UndefinedVariable
@@ -576,9 +558,10 @@ def get_contents_page(num_page, user):
     return content_nb, nb_ct_pages, content_list
 
 
-def get_content_tags(limit=None, steps=10):
-    if limit is None:
-        return Tag.objects.cloud_for_model(Content, steps=steps)
-    else :
-        return Tag.objects.cloud_for_model(Content, steps=steps)[:limit]
-        
+# def get_content_tags(limit=None, steps=10):
+#     return None
+#     if limit is None:
+#         return Tag.objects.cloud_for_model(Content, steps=steps)
+#     else :
+#         return Tag.objects.cloud_for_model(Content, steps=steps)[:limit]
+
